Return a data.frame with latest summary information for a set of major financial market indices.
Arguments
- region
character, default =NULL(no filtering) - Select a region for filter out the results.Valid regionvalues"US","AU","CA","FR","DE","HK","US","IT","ES","GB","IN"- .verbose
logical, default =FALSE- Logical flag indicating whether to print verbose output for debugging or informational purposes.
Value
A data.frame with 15 rows and 38 variables. Each row corresponds to a market index and includes the following information:
Information on the asset:
symbol,shortname,longname,exchange,region,currencyMarket time info, mostly associated with the pricing info:
regularmarkettime_raw,regularmarkettime_fmtMarket pricing info:
regularmarketprice_raw,regularmarketchange_raw,regularmarketchangepercent_raw, etc.Metadata such as
marketstate,quotetype,pricehint,exchangedatadelayedby,hasprepostmarketdataOther fields such as
cryptotradeable,tradeable,triggerable,contracts, etc.
See also
For more details on the 'last_' family of functions see the help vignette:
vignette("last_family", package = "financr")